;; Tests for rst-compile  -*- lexical-binding: t -*-

(add-to-list 'load-path ".")
(load "init" nil t)
(init-rst-ert t)

(ert-deftest compile-asserts ()
  "Check some assertions."
  (should (equal ert-Buf-point-char "\^@"))
  (should (equal ert-Buf-mark-char "\^?"))
  )

(defun run-rst-compile (use-alt toolsets)
  "Run `rst-compile' and return the compile command used.
The returned command uses 'ert_rst-compile' as the base file name so it can be
checked easily. USE-ALT ist given to `rst-compile' and `rst-compile-toolsets'
is set to TOOLSETS if non-nil."
  (let* ((prefix "ert_rst-compile")
	 (file (make-temp-file prefix nil ".rst")))
    ;; Also seems to change the directory
    (set-visited-file-name file t)
    (let ((rst-compile-toolsets (or toolsets rst-compile-toolsets)))
      (set-buffer-modified-p nil)
      (mapcar (lambda (s)
		(replace-regexp-in-string (concat prefix "[^.]*\\.")
					  (concat prefix ".") s t t))
	      (rst-compile-command use-alt)))))

(ert-deftest rst-compile ()
  "Tests for `rst-compile'."
    (should (ert-equal-buffer-return
	     '(run-rst-compile nil nil)
	     ""
	     t
	     '("rst2html.py"
	       "ert_rst-compile.rst" "ert_rst-compile.html")))
    (should (ert-equal-buffer-return
	     '(run-rst-compile t nil)
	     ""
	     t
	     '("rst2latex.py"
	       "ert_rst-compile.rst" "ert_rst-compile.tex")))
    (should (ert-equal-buffer-return
	     '(run-rst-compile nil '((html "true" ".htm" "--option")))
	     ""
	     t
	     '("true" "--option"
	       "ert_rst-compile.rst" "ert_rst-compile.htm")))
    )
